<?php
/**
 *  Register Field Groups
 *
 *  The register_field_group function accepts 1 array which holds the relevant data to register a field group
 *  You may edit the array as you see fit. However, this may result in errors if the array is not compatible with ACF
 */

if(function_exists("register_field_group"))
{
	register_field_group(array (
		'id' => 'acf_frontend-submission-emails-setup',
		'title' => 'Frontend Submission Emails Setup',
		'fields' => array (
			array (
				'key' => 'field_52330bb7f503a',
				'label' => 'Receive Email On Submission',
				'name' => 'receive_email_on_submission',
				'type' => 'true_false',
				'instructions' => 'Enable the following option if you wish to receive an email when a user submits a listing from the frontend.',
				'message' => 'Receive Email On Submission',
				'default_value' => 1,
			),
			array (
				'key' => 'field_52330becf503b',
				'label' => 'Receive Email On Listing Modification',
				'name' => 'receive_email_on_listing_modification',
				'type' => 'true_false',
				'instructions' => 'Enable the following option if you wish to receive an email when a user modifies a listing.',
				'message' => 'Receive Email On Submission',
				'default_value' => 1,
			),
			array (
				'key' => 'field_52330c24f503c',
				'label' => 'Receive Email On Claiming Submission',
				'name' => 'receive_email_on_claiming_submission',
				'type' => 'true_false',
				'instructions' => 'Enable the following option if you wish to receive an email when a claiming has been submitted.',
				'message' => 'Receive Email On Claiming Submission',
				'default_value' => 1,
			),
			array (
				'key' => 'field_52334e87be478',
				'label' => 'Send Email On Submission',
				'name' => 'send_email_on_submission',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you wish to send an email to the user that submitted the listing. This email will be sent as confirmation that the listing has been received and it will be reviewed.',
				'message' => 'Send Email On Submission',
				'default_value' => 1,
			),
			array (
				'key' => 'field_52334ec5be479',
				'label' => 'Send Email On Listing Modification',
				'name' => 'send_email_on_listing_modification',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you wish to send an email to the user when he has made a modification to one of his listings.',
				'message' => 'Send Email On Listing Modification',
				'default_value' => 1,
			),
			array (
				'key' => 'field_52341c8761551',
				'label' => 'Send Email On Listing Approval',
				'name' => 'send_email_on_listing_approval',
				'type' => 'true_false',
				'instructions' => 'Enable the following option if you wish to send an email to listing author informing him of the approval of his listing.',
				'message' => '',
				'default_value' => 1,
			),
		),
		'location' => array (
			array (
				array (
					'param' => 'options_page',
					'operator' => '==',
					'value' => 'acf-options-emails-setup',
					'order_no' => 0,
					'group_no' => 0,
				),
			),
		),
		'options' => array (
			'position' => 'normal',
			'layout' => 'default',
			'hide_on_screen' => array (
			),
		),
		'menu_order' => 0,
	));
	register_field_group(array (
		'id' => 'acf_listings-categories',
		'title' => 'Listings Categories',
		'fields' => array (
			array (
				'key' => 'field_51e14d7a0235b',
				'label' => 'Marker Type',
				'name' => 'marker_type',
				'type' => 'image',
				'instructions' => 'Set the marker image for this category. If left blank, the default one will be displayed.',
				'save_format' => 'url',
				'preview_size' => 'thumbnail',
				'library' => 'uploadedTo',
			),
			array (
				'key' => 'field_51e9103be08c5',
				'label' => 'Featured Marker',
				'name' => 'featured_marker',
				'type' => 'image',
				'instructions' => 'Set the marker image if the listing is featured.',
				'save_format' => 'url',
				'preview_size' => 'thumbnail',
				'library' => 'all',
			),
			array (
				'key' => 'field_51e9103be08c7',
				'label' => 'Category Slider Shortcode',
				'name' => 'tdp_category_slider',
				'type' => 'text',
				'instructions' => 'If needed you can replace the map into the listings category page with a slider to add a slider just add the LayerSlider shortcode here. If not needed just leave this field blank.',
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
			array (
				'key' => 'field_51e450d2e1208',
				'label' => 'Taxonomy Description',
				'name' => 'taxonomy_description',
				'type' => 'wysiwyg',
				'instructions' => 'Use this editor to customize the text that will be displayed above every taxonomy page.',
				'default_value' => '',
				'toolbar' => 'full',
				'media_upload' => 'no',
			),
		),
		'location' => array (
			array (
				array (
					'param' => 'ef_taxonomy',
					'operator' => '==',
					'value' => 'listings_categories',
					'order_no' => 0,
					'group_no' => 0,
				),
			),
		),
		'options' => array (
			'position' => 'normal',
			'layout' => 'no_box',
			'hide_on_screen' => array (
			),
		),
		'menu_order' => 0,
	));
	register_field_group(array (
		'id' => 'acf_listings-theme-settings',
		'title' => 'Listings Theme Settings',
		'fields' => array (
			array (
				'key' => 'field_51dfcf4a06d17',
				'label' => 'Main Settings',
				'name' => '',
				'type' => 'tab',
			),
			array (
				'key' => 'field_51e03ce92728b',
				'label' => 'Map Main Settings',
				'name' => '',
				'type' => 'message',
				'message' => '<h1>Google Map Main Settings</h1>
	<h2>Use the following settings to control the general style of the google map.</h2>',
			),
			array (
				'key' => 'field_51e91b63e9060',
				'label' => 'Enable Geolocation',
				'name' => 'enable_geolocation',
				'type' => 'true_false',
				'instructions' => 'Select if you wish to enable the geolocation service on the map.',
				'message' => 'Enable Geolocation',
				'default_value' => 0,
			),
			array (
				'key' => 'field_51e91b63e9geo',
				'label' => 'Load Geolocation On Click',
				'name' => 'enable_geolocation_on_click',
				'type' => 'true_false',
				'instructions' => 'Select if you wish to enable the geolocation service only on the click on the "location" button onto the map. If unselected, the geolocation service will start on page load.',
				'message' => 'Enable Geolocation On Click',
				'default_value' => 0,
			),
			array (
				'key' => 'field_51e91b63e90cc',
				'label' => 'Geolocation Text',
				'name' => 'geolocation_text',
				'type' => 'text',
				'instructions' => 'Set the text that you wish to display when the postion of the user has been found. This works only when you enabled the ajax system.',
				'default_value' => 'Your Are Here!',
			),
			array (
				'key' => 'field_51daa8aefa1dd',
				'label' => 'Geolocation Custom Pin Image',
				'name' => 'geolocation_pin',
				'type' => 'image',
				'instructions' => 'Set the image that you wish to use for the geolocated pin on the map. This works only when you enabled the ajax system.',
				'save_format' => 'url',
				'preview_size' => 'thumbnail',
				'library' => 'all',
			),
			array (
				'key' => 'field_51e03f06f3786',
				'label' => 'Map Type Control',
				'name' => 'map_type_control',
				'type' => 'true_false',
				'instructions' => 'The initial enabled/disabled state of the Map type control.',
				'message' => 'Display Map Type Control',
				'default_value' => 0,
			),
			array (
				'key' => 'field_51e03d75f3783',
				'label' => 'Is Draggable ?',
				'name' => 'is_draggable',
				'type' => 'true_false',
				'instructions' => 'If false, prevents the map from being dragged. Dragging is enabled by default.',
				'message' => 'Is draggable ?',
				'default_value' => 1,
			),
			array (
				'key' => 'field_51e03e93f3785',
				'label' => 'Keyboard Shortcuts',
				'name' => 'keyboard_shortcuts',
				'type' => 'true_false',
				'instructions' => 'If disabled, prevents the map from being controlled by the keyboard. Keyboard shortcuts are enabled by default.',
				'message' => 'Enable Keyboard Shortcuts',
				'default_value' => 1,
			),
			array (
				'key' => 'field_51e03f49f3787',
				'label' => 'Map Type ID',
				'name' => 'map_type_id',
				'type' => 'select',
				'instructions' => 'The initial Map mapTypeId.',
				'required' => 1,
				'choices' => array (
					'HYBRID' => 'HYBRID',
					'ROADMAP' => 'ROADMAP',
					'SATELLITE' => 'SATELLITE',
					'TERRAIN' => 'TERRAIN',
				),
				'default_value' => 'ROADMAP',
				'allow_null' => 0,
				'multiple' => 0,
			),
			array (
				'key' => 'field_51e041959a665',
				'label' => 'Street View Control',
				'name' => 'street_view_control',
				'type' => 'true_false',
				'instructions' => 'The initial enabled/disabled state of the Street View Pegman control. This control is part of the default UI, and should be set to false when displaying a map type on which the Street View road overlay should not appear (e.g. a non-Earth map type).',
				'message' => 'Display Street View Control',
				'default_value' => 0,
			),
			array (
				'key' => 'field_51e041c89a666',
				'label' => 'Scrollwheel Control',
				'name' => 'scrollwheel_control',
				'type' => 'true_false',
				'instructions' => 'If false, disables scrollwheel zooming on the map. The scrollwheel is enabled by default.',
				'message' => 'Scrollwheel Control',
				'default_value' => 0,
			),
			array (
				'key' => 'field_51e0432b9a668',
				'label' => 'Zoom Control',
				'name' => 'zoom_control',
				'type' => 'true_false',
				'instructions' => 'The enabled/disabled state of the Zoom control.',
				'message' => 'Enable Zoom Control',
				'default_value' => 1,
			),
			array (
				'key' => 'field_multiple_address',
				'label' => 'Markers With Same Address?',
				'name' => 'multiple_marker_address',
				'type' => 'true_false',
				'instructions' => 'Enable this option if your listings are likely gonna have multiple markers on the same address',
				'message' => 'Markers with same address?',
				'default_value' => 0,
			),
			array (
				'key' => 'field_disable_poi',
				'label' => 'Disable Point of Interests',
				'name' => 'disable_poi',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you wish to disable point of interests on the map',
				'message' => 'Disable Point of Interests',
				'default_value' => 0,
			),

			array (
				'key' => 'field_cluster_image',
				'label' => 'Custom Clusters Image',
				'name' => 'cluster_image',
				'type' => 'image',
				'instructions' => 'Set the image that you wish to use for the clusters on the map. This works only for the AJAX MAP.',
				'save_format' => 'url',
				'preview_size' => 'thumbnail',
				'library' => 'all',
			),
			array (
				'key' => 'field_51e14fe31b346',
				'label' => 'General Settings',
				'name' => '',
				'type' => 'tab',
			),
			array (
				'key' => 'field_51e91b63e90exp',
				'label' => 'Enable Listings Expiration',
				'name' => 'enable_listings_expire',
				'type' => 'true_false',
				'instructions' => 'Select if you wish to enable expiration for your listings. The expiration date of the listings is grabbed from the expiration date of the membership of the user.',
				'message' => 'Enable Expiration',
				'default_value' => 0,
			),
			array (
				'key' => 'field_51e91b63e90aj',
				'label' => 'Enable System',
				'name' => 'enable_ajax_map',
				'type' => 'true_false',
				'instructions' => 'Select if you wish to enable the ajax version of certain components of your website. Useful if your website has a lot of listings.',
				'message' => 'Enable Ajax System',
				'default_value' => 0,
			),
			array (
				'key' => 'field_51e285897e548',
				'label' => 'Map ToolTip Content',
				'name' => 'map_tooltip_content',
				'type' => 'radio',
				'instructions' => 'Set the content of the tooltip on the map that appears when a marker is clicked.',
				'choices' => array (
					'Listing Address' => 'Listing Address',
					'Listing Excerpt' => 'Listing Excerpt',
				),
				'other_choice' => 0,
				'save_other_choice' => 0,
				'default_value' => 'Listing Address',
				'layout' => 'horizontal',
			),
			array (
				'key' => 'field_51e2a6fc0c3d4',
				'label' => 'How Many Featured Listings',
				'name' => 'how_many_featured_listings',
				'type' => 'number',
				'instructions' => 'Choose how many featured listings you want to display into the homepage sidebar.',
				'default_value' => 10,
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'min' => 1,
				'max' => 999,
				'step' => '',
			),
			array (
				'key' => 'field_51e2c8db372b0',
				'label' => 'How Many Normal Listings',
				'name' => 'how_many_normal_listings',
				'type' => 'number',
				'instructions' => 'Set how many listings you want to display into the sidebar.',
				'default_value' => 15,
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'min' => 1,
				'max' => 999,
				'step' => '',
			),
			array (
				'key' => 'field_51e2e0a2cca02',
				'label' => 'Display Map In Taxonomies Pages',
				'name' => 'display_map_in_taxonomies_pages',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you wish to display the map of the current taxonomy below the header.',
				'message' => 'Display Map In Taxonomies Pages',
				'default_value' => 1,
			),
			array (
				'key' => 'field_51e2e0a2cca0e',
				'label' => 'Override ToolTip Links To Website Hyperlink',
				'name' => 'override_hyperlink',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you wish to override the default behaviour of the popup links, if enabled, the links of the marker tooltip will redirect to the listing website',
				'message' => 'Override ToolTip Links To Website Hyperlink',
				'default_value' => 0,
			),
			array (
				'key' => 'field_51e57d91e3cd5',
				'label' => 'Listings Per Page',
				'name' => 'listings_per_page',
				'type' => 'number',
				'instructions' => 'Select how many listings you want to display on each inner page.',
				'default_value' => 10,
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'min' => 3,
				'max' => 100,
				'step' => '',
			),
			array (
				'key' => 'field_51e2e0a2cclis',
				'label' => 'Current Taxonomy Child Categories/Locations',
				'name' => 'display_child_items',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you wish to display child categories/locations in taxonomies pages, before the listings.',
				'message' => 'Display Current Taxonomy Child Categories/Locations',
				'default_value' => 0,
			),
			array (
				'key' => 'field_51e2e9e297f7f',
				'label' => 'Taxonomy Layout',
				'name' => 'taxonomy_layout',
				'type' => 'select',
				'instructions' => 'Select the layout for the internal listings pages.',
				'choices' => array (
					'Sidebar Right' => 'Sidebar Right',
					'Sidebar Left' => 'Sidebar Left',
					'Fullwidth' => 'Fullwidth',
				),
				'default_value' => 'Fullwidth',
				'allow_null' => 0,
				'multiple' => 0,
			),
		

			array (
				'key' => 'field_51e818df30999',
				'label' => 'Enable Ratings System',
				'name' => 'enable_ratings_system',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you wish to enable the rating systems, this allows users to leave reviews on listings. <strong>Disable this option if you wish to use the GD Star Rating Plugin.</strong>',
				'message' => 'Enable Ratings System',
				'default_value' => 1,
			),

			array (
				'key' => 'field_51e818df30986',
				'label' => 'Enable Multi Ratings System',
				'name' => 'enable_multi_ratings_system',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you wish to enable the multi rating systems. You must install the GD Star Rating Plugin first.',
				'message' => 'Enable Multi Ratings System',
				'default_value' => 1,
			),

			array (
				'key' => 'field_52d01fee64b00',
				'label' => __('Multi Rating Box Position'),
				'name' => 'multi_rating_box_position',
				'type' => 'select',
				'instructions' => __('Select where you\'d like to display the multi rating box.'),
				'choices' => array (
					'Above Comment Form' => 'Above Comment Form',
					'Below Listing Content' => 'Below Listing Content',
				),
				'default_value' => 'Below Listing Content',
				'allow_null' => 0,
				'multiple' => 0,
			),
			array (
				'key' => 'field_52d0206f64b01',
				'label' => __('Multi Set ID Number'),
				'name' => 'multi_set_id_number',
				'type' => 'number',
				'instructions' => 'Enter the id number of the multi set that you created through the GD Start Rating Plugin. To create a rating set you need to install the GD Star Rating plugin first, then navigate to "GD Star Rating -> Multi Sets". 
	
	Note: when setting up the multi set, locate the setting "Insertion" and select the option "No". ',
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'min' => '',
				'max' => '',
				'step' => '',
			),
			array (
				'key' => 'field_52d0206f64b02',
				'label' => __('Align Rating Stars'),
				'name' => 'align_rating',
				'type' => 'number',
				'instructions' => 'Use this option to re-align the rating stars into the taxonomies pages.',
				'default_value' => '25',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'min' => '',
				'max' => '',
				'step' => '',
			),

			array (
				'key' => 'field_51e818df30186',
				'label' => 'Enable Promotions System',
				'name' => 'enable_promotions_system',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you wish to enable the promotions systems, this allows users to publish promotions for their listings.',
				'message' => 'Enable Promotions System',
				'default_value' => 0,
			),
			array (
				'key' => 'field_5224b7eff05d5',
				'label' => 'Display Featured Listings Carousel',
				'name' => 'display_featured_listings_carousel',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you want to display a featured properties carousel above the listings in taxonomies pages.',
				'message' => '',
				'default_value' => 1,
			),
			array (
				'key' => 'field_51e58a5d37f0c',
				'label' => 'Single Listing',
				'name' => '',
				'type' => 'tab',
			),
			array (
				'key' => 'field_51e58a9637f0d',
				'label' => 'Display Google Map Below The Header',
				'name' => 'display_google_map_below_the_header',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you wish to display a map of the current listing below the header.',
				'message' => 'Display Google Map Below The Header',
				'default_value' => 1,
			),
			array (
				'key' => 'field_51e58bdb85edd7',
				'label' => 'Display Map On Page Load',
				'name' => 'display_single_map_page_load',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you wish to display the map on page load and not on button click.',
				'message' => 'Display Map on page load',
				'default_value' => 0,
			),
			array (
				'key' => 'field_street_view',
				'label' => 'Add Street View Control To Single Listing',
				'name' => 'display_google_streetview_below_the_header',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you wish to Add Street View Control To Single Listing for the map below the header',
				'message' => 'Display StreetView Below The Header',
				'default_value' => 0,
			),
			array (
				'key' => 'field_51e58b0137f0f',
				'label' => 'Single Listing Page Layout',
				'name' => 'single_listing_page_layout',
				'type' => 'select',
				'instructions' => 'Select the layout for the single listing page.',
				'choices' => array (
					'Sidebar Right' => 'Sidebar Right',
					'Sidebar Left' => 'Sidebar Left',
				),
				'default_value' => 'Sidebar Right',
				'allow_null' => 0,
				'multiple' => 0,
			),
			array (
				'key' => 'field_51e58bdb85ed7',
				'label' => 'Display Social Sharing Icons',
				'name' => 'display_social_sharing_icons',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you wish to display social sharing links.',
				'message' => 'Display Social Sharing Icons',
				'default_value' => 1,
			),
			array (
				'key' => 'field_51e7c01eaf608',
				'label' => 'Sharing Text',
				'name' => 'sharing_text',
				'type' => 'text',
				'instructions' => 'Set the message that will be used automatically when sharing a listing.',
				'default_value' => 'I found a nice listing, have a look:',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
			array (
				'key' => 'field_51e6766e9c512',
				'label' => 'Display Big Title & Brief Info',
				'name' => 'display_big_title',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you wish to display a big title of the listing at the top of the page, it will also display few more brief information.',
				'message' => 'Display Big Title & Brief Info',
				'default_value' => 1,
			),
			array (
				'key' => 'field_51e689513c86f',
				'label' => 'Display Featured Listing Tag',
				'name' => 'display_featured_listing_tag',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you wish to display the featured listing notice tag next to the listing title.',
				'message' => 'Display Featured Listing Tag',
				'default_value' => 1,
			),
			array (
				'key' => 'field_51e690a608280',
				'label' => 'Display Listings Views',
				'name' => 'display_listings_views',
				'type' => 'true_false',
				'instructions' => 'Enable the options if you wish to display listing views.',
				'message' => 'Display Listings Views',
				'default_value' => 1,
			),
			array (
				'key' => 'field_51e6973bef180',
				'label' => 'Single Listing Image Width',
				'name' => 'single_listing_image_width',
				'type' => 'text',
				'instructions' => 'Set the image width of the single listing image.',
				'default_value' => 670,
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
			array (
				'key' => 'field_51e69765ef181',
				'label' => 'Single Listing Image Height',
				'name' => 'single_listing_image_height',
				'type' => 'text',
				'instructions' => 'Set the image height of the single listing image.',
				'default_value' => 300,
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
			array (
				'key' => 'field_522dfeff6f87b',
				'label' => 'Enable Print Listing Button',
				'name' => 'enable_print_listing_button',
				'type' => 'true_false',
				'instructions' => 'Enable this option if	you wish to display the print listing button.',
				'message' => '',
				'default_value' => 1,
			),
			array (
				'key' => 'field_522dff256f87c',
				'label' => 'Enable Send To A Friend Form',
				'name' => 'enable_send_to_a_friend_form',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you wish to display a form where users can send a link to a friend with the current listing.',
				'message' => '',
				'default_value' => 1,
			),
			array (
				'key' => 'field_522dff256f87ccdir',
				'label' => 'Enable Get Directions Form',
				'name' => 'enable_get_directions_form',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you wish to display a form where users can get directions to the current listing.',
				'message' => '',
				'default_value' => 1,
			),
			array (
				'key' => 'field_522dff256f87ccfavs',
				'label' => 'Enable Favorites System',
				'name' => 'enable_favorites_system',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you wish to allow users to favorites listings.',
				'message' => '',
				'default_value' => 0,
			),
			array (
				'key' => 'field_522e08008e587',
				'label' => 'Claim Listings',
				'name' => '',
				'type' => 'tab',
			),
			array (
				'key' => 'field_522e077a77e60',
				'label' => 'Enable Claim Listing Component',
				'name' => 'enable_claim_listing_component',
				'type' => 'true_false',
				'instructions' => 'Enable the following option if you wish to enable the claim listing component. This component allows users to claim listings on your website.',
				'message' => '',
				'default_value' => 0,
			),
			array (
				'key' => 'field_522e08108e588',
				'label' => 'Introduction Message',
				'name' => 'claiming_intro_message',
				'type' => 'wysiwyg',
				'instructions' => 'If you wish here you can add a message that will be displayed on top of the form before claiming it.',
				'conditional_logic' => array (
					'status' => 1,
					'rules' => array (
						array (
							'field' => 'field_522e077a77e60',
							'operator' => '==',
							'value' => '1',
						),
					),
					'allorany' => 'all',
				),
				'default_value' => '',
				'toolbar' => 'full',
				'media_upload' => 'no',
			),
			array (
				'key' => 'field_522ef386bc670',
				'label' => 'Successfully Claimed Page',
				'name' => 'successfully_claimed_page',
				'type' => 'page_link',
				'instructions' => 'Select the page where you want to redirect users after submitting their claiming. This page is useful if you would like to display information on how they would receive a response for their claim.',
				'post_type' => array (
					0 => 'page',
				),
				'allow_null' => 0,
				'multiple' => 0,
			),
			array (
				'key' => 'field_522f363494bc7',
				'label' => 'Listings Submission',
				'name' => '',
				'type' => 'tab',
			),
			array (
				'key' => 'field_522f363f94bc8',
				'label' => 'Default Listing Submission Status',
				'name' => 'default_listing_submission_status',
				'type' => 'radio',
				'instructions' => 'Select the default status of the listing submitted from the front-end.',
				'choices' => array (
					'publish' => 'publish',
					'draft' => 'draft',
				),
				'other_choice' => 0,
				'save_other_choice' => 0,
				'default_value' => 'draft',
				'layout' => 'vertical',
			),
			array (
				'key' => 'field_52320a252d721',
				'label' => 'Default Listing Edit Status',
				'name' => 'default_listing_edit_status',
				'type' => 'radio',
				'instructions' => 'Select the default status of the listing when is edited from the frontend. It\'s recommended that you set this as draft, so you can verify the kind of changes the user has made.',
				'choices' => array (
					'publish' => 'publish',
					'draft' => 'draft',
				),
				'other_choice' => 0,
				'save_other_choice' => 0,
				'default_value' => 'draft',
				'layout' => 'vertical',
			),
			array (
				'key' => 'field_5230406f11e95',
				'label' => 'Redirect On Submission',
				'name' => 'redirect_on_submission',
				'type' => 'page_link',
				'instructions' => 'Select the page where you want to redirect users after submitting a listing from the frontend. Usually this page is where you show a message explaining what happens after they submit a listing.',
				'post_type' => array (
					0 => 'page',
				),
				'allow_null' => 0,
				'multiple' => 0,
			),
			array (
				'key' => 'field_disable_social',
				'label' => 'Disable Social Profiles For Listings',
				'name' => 'disable_social_profiles',
				'type' => 'true_false',
				'instructions' => 'Check The Option To Disable social profiles submission for listings from the frontend',
				'message' => 'Disable Social Profiles',
				'default_value' => 0,
			),
			array (
				'key' => 'field_5231baf0226e8',
				'label' => 'Automatically Set Featured Listing For These Memberships',
				'name' => 'automatically_set_featured_listing_for_these_memberships',
				'type' => 'text',
				'instructions' => 'Enter the <strong>IDs</strong> of the memberships that are allowed to set listings as featured. Separate multiple memberships with a comma. E.g: 1, 2 etc..',
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
			array (
				'key' => 'field_5231bf6e48659',
				'label' => 'Unauthorized Message ',
				'name' => 'membership_required_submission_message',
				'type' => 'wysiwyg',
				'instructions' => 'Enter the message that will be displayed to users that do not have any membership, are not registered or do not have enough posting allowance left to submit a listing.',
				'default_value' => 'It looks like you are not authorized to access this page. You need to register and be logged in or you ran out of posting allowance.',
				'toolbar' => 'full',
				'media_upload' => 'no',
			),
			array (
				'key' => 'field_52320a572d722',
				'label' => 'Successful Listing Edit Confirmation Message',
				'name' => 'successful_listing_edit_confirmation_message',
				'type' => 'wysiwyg',
				'instructions' => 'Set a message to display to the user when he edits his listings.',
				'default_value' => '<p>Please note: your listing will be reviewed and we will then re-publish your listing.</p>',
				'toolbar' => 'full',
				'media_upload' => 'yes',
			),
		),
		'location' => array (
			array (
				array (
					'param' => 'options_page',
					'operator' => '==',
					'value' => 'acf-options-listings-settings',
					'order_no' => 0,
					'group_no' => 0,
				),
			),
		),
		'options' => array (
			'position' => 'normal',
			'layout' => 'default',
			'hide_on_screen' => array (
			),
		),
		'menu_order' => 0,
	));
	register_field_group(array (
		'id' => 'acf_theme-options',
		'title' => 'Theme Options',
		'fields' => array (
			array (
				'key' => 'field_51daa84afa13a',
				'label' => 'General Settings',
				'name' => '',
				'type' => 'tab',
			),
			array (
				'key' => 'field_51daa8aefa13b',
				'label' => 'Custom Logo',
				'name' => 'custom_logo',
				'type' => 'image',
				'instructions' => 'Upload your custom logo here.',
				'save_format' => 'url',
				'preview_size' => 'thumbnail',
				'library' => 'all',
			),
			array (
				'key' => 'field_51daa908d13da',
				'label' => 'Custom Favicon',
				'name' => 'custom_favicon',
				'type' => 'image',
				'instructions' => 'Upload your custom favicon here.',
				'save_format' => 'url',
				'preview_size' => 'thumbnail',
				'library' => 'all',
			),
			array (
				'key' => 'field_51daa927d13db',
				'label' => 'Google Font Url',
				'name' => 'google_font_url',
				'type' => 'text',
				'instructions' => 'Enter the google font url here.',
				'default_value' => 'http://fonts.googleapis.com/css?family=Roboto:400,100,100italic,300,300italic,400italic,500,500italic,700,700italic,900,900italic',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
			array (
				'key' => 'field_51daa968d13dc',
				'label' => 'Google Font Name',
				'name' => 'google_font_name',
				'type' => 'text',
				'instructions' => 'Enter the font family name of the font.',
				'default_value' => 'Roboto',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
			array (
				'key' => 'field_51daace47a610',
				'label' => 'Display Breadcrumb',
				'name' => 'display_breadcrumb',
				'type' => 'true_false',
				'message' => 'Display Breadcrumb',
				'default_value' => 1,
			),
			array (
				'key' => 'field_51daaaf15a4af',
				'label' => 'Disable Featured Images On Pages',
				'name' => 'disable_featured_images_on_pages',
				'type' => 'true_false',
				'instructions' => 'Check The Option To Disable Featured Images On Regular Pages.',
				'message' => 'Disable Featured Images On Pages',
				'default_value' => 0,
			),
			array (
				'key' => 'field_522de6d398459',
				'label' => 'Search Results Page',
				'name' => 'search_results_page',
				'type' => 'page_link',
				'instructions' => 'Select the page with the "Search Results" page template applied. If you don\'t set this option, your listing search form won\'t work.',
				'post_type' => array (
					0 => 'page',
				),
				'allow_null' => 0,
				'multiple' => 0,
			),
			array (
				'key' => 'field_51daaaf15a4ae',
				'label' => 'Enable Grid Layout In Search Results',
				'name' => 'enable_grid_in_search_results',
				'type' => 'true_false',
				'instructions' => 'Check The Option To enable the grid layout in search results.',
				'message' => 'Enable Grid Layout In Search Results',
				'default_value' => 0,
			),
			array (
				'key' => 'field_522decfb55792',
				'label' => 'Results Per Page',
				'name' => 'results_per_page',
				'type' => 'number',
				'instructions' => 'Set how many results you want to display per page.',
				'default_value' => 10,
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'min' => 1,
				'max' => '',
				'step' => '',
			),
			array (
				'key' => 'field_rtl',
				'label' => 'Load RTL Stylesheet',
				'name' => 'add_rtl_support',
				'type' => 'true_false',
				'instructions' => 'Enable the following option if you wish to load the RTL stylesheet for RTL languages',
				'message' => 'Load RTL Css',
				'default_value' => 0,
			),
			array (
				'key' => 'field_lang',
				'label' => 'Display WPML Language Switcher Inside the header',
				'name' => 'add_lang_switcher',
				'type' => 'true_false',
				'instructions' => 'Enable the following option if you wish to add the WPML Language switcher inside the header. Note you need the WPML plugin enabled to make it work.',
				'message' => 'Load Language Switcher',
				'default_value' => 0,
			),
			array (
				'key' => 'field_lnames',
				'label' => 'Force First Name And Last Name In Membership Checkout',
				'name' => 'force_name_fields',
				'type' => 'true_false',
				'instructions' => 'Enable the following option if you wish to Force First Name And Last Name In Membership Checkout.',
				'message' => 'Force First Name And Last Name In Membership Checkout',
				'default_value' => 0,
			),
			array (
				'key' => 'field_51daab675a4b0',
				'label' => 'Social Links',
				'name' => 'social_links',
				'type' => 'repeater',
				'instructions' => 'Add Social links here.',
				'sub_fields' => array (
					array (
						'key' => 'field_51daab925a4b1',
						'label' => 'Social Platform',
						'name' => 'social_platform',
						'type' => 'select',
						'column_width' => '',
						'choices' => array (
							'icon-dribbble' => 'icon-dribbble-1',
							'icon-mail-alt' => 'icon-mail-alt',
							'icon-facebook' => 'icon-facebook-2',
							'icon-flickr' => 'icon-flickr-1',
							'icon-gplus' => 'icon-gplus-2',
							'icon-instagramm' => 'icon-instagram-1',
							'icon-linkedin' => 'icon-linkedin-1',
							'icon-pinterest-circled' => 'icon-pinterest',
							'icon-skype' => 'icon-skype-1',
							'icon-twitter' => 'icon-twitter',
							'icon-youtube' => 'icon-youtube',
						),
						'default_value' => '',
						'allow_null' => 0,
						'multiple' => 0,
					),
					array (
						'key' => 'field_51daac165a4b2',
						'label' => 'Profile Url',
						'name' => 'profile_url',
						'type' => 'text',
						'instructions' => 'Enter the url of the profile',
						'column_width' => '',
						'default_value' => '#',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'formatting' => 'html',
						'maxlength' => '',
					),
				),
				'row_min' => 0,
				'row_limit' => '',
				'layout' => 'row',
				'button_label' => 'Add New Social',
			),
			array (
				'key' => 'field_51daaedf65db6',
				'label' => 'Header Settings',
				'name' => '',
				'type' => 'tab',
			),
			array (
				'key' => 'field_51e07710f30d3',
				'label' => 'Display Topbar',
				'name' => 'display_topbar',
				'type' => 'true_false',
				'instructions' => 'Select if you wish to display the header topbar.',
				'message' => 'Display Topbar',
				'default_value' => 1,
			),
			array (
				'key' => 'field_51dec3bd4ac7a',
				'label' => 'Top Bar Intro Text',
				'name' => 'top_bar_intro_text',
				'type' => 'wysiwyg',
				'instructions' => 'Enter the content that will be displayed on top of the header.',
				'conditional_logic' => array (
					'status' => 1,
					'rules' => array (
						array (
							'field' => 'field_51e07710f30d3',
							'operator' => '==',
							'value' => '1',
						),
					),
					'allorany' => 'all',
				),
				'default_value' => 'The premier destination for premium listings. <a href="#">Submit Your Listing Now »</a>',
				'toolbar' => 'basic',
				'media_upload' => 'yes',
			),
			array (
				'key' => 'field_51dab0bc14efa',
				'label' => 'Footer Settings',
				'name' => '',
				'type' => 'tab',
			),
			array (
				'key' => 'field_51dab0ee14efb',
				'label' => 'Widgetized Columns',
				'name' => 'widgetized_columns',
				'type' => 'select',
				'instructions' => 'Select How Many Columns Your Footer Should Have.',
				'choices' => array (
					4 => 4,
					3 => 3,
					2 => 2,
				),
				'default_value' => 3,
				'allow_null' => 0,
				'multiple' => 0,
			),
			array (
				'key' => 'field_51dab10c14efc',
				'label' => 'Copyright Text',
				'name' => 'copyright_text',
				'type' => 'wysiwyg',
				'instructions' => 'Enter Copyright Text Here',
				'default_value' => 'Copyright © 2013. Developed By <a href="#">ThemesDepot</a> & Powered By <a href="#">WordPress</a> - Hosted By <a href="http://www.eleven2.com/2582.html">Eleven2</a>',
				'toolbar' => 'basic',
				'media_upload' => 'no',
			),
			array (
				'key' => 'field_51dab1b06c043',
				'label' => 'Blog Layout',
				'name' => '',
				'type' => 'tab',
			),
			array (
				'key' => 'field_51daef25c94a8',
				'label' => 'Blog Header Image',
				'name' => 'blog_header_image',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you want to set an image for the blog header.',
				'message' => 'Enable Blog Header Image',
				'default_value' => 0,
			),
			array (
				'key' => 'field_51daef51c94a9',
				'label' => 'Blog Image Url',
				'name' => 'blog_image_url',
				'type' => 'image',
				'conditional_logic' => array (
					'status' => 1,
					'rules' => array (
						array (
							'field' => 'field_51daef25c94a8',
							'operator' => '==',
							'value' => '1',
						),
					),
					'allorany' => 'all',
				),
				'save_format' => 'url',
				'preview_size' => 'thumbnail',
				'library' => 'all',
			),
			array (
				'key' => 'field_51dab2066c044',
				'label' => 'Blog Intro text',
				'name' => 'blog_intro_text',
				'type' => 'wysiwyg',
				'default_value' => '<h1>Atlas Blog</h1>
	<h2>This introductory text can be changed from the options panel.</h2>',
				'toolbar' => 'full',
				'media_upload' => 'no',
			),
			array (
				'key' => 'field_51db05f5630ec',
				'label' => 'Blog Sidebar Position',
				'name' => 'blog_sidebar_position',
				'type' => 'select',
				'instructions' => 'Select the position of the sidebar',
				'choices' => array (
					'Sidebar Right' => 'Sidebar Right',
					'Sidebar Left' => 'Sidebar Left',
				),
				'default_value' => 'Sidebar Right',
				'allow_null' => 0,
				'multiple' => 0,
			),
			array (
				'key' => 'field_51dab2b56c045',
				'label' => 'Featured Image Width',
				'name' => 'featured_image_width',
				'type' => 'text',
				'instructions' => 'Default Featured Image Size.',
				'default_value' => 670,
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
			array (
				'key' => 'field_51dab2d36c046',
				'label' => 'Featured Image Height',
				'name' => 'featured_image_height',
				'type' => 'text',
				'instructions' => 'Default Blog Featured Image Height',
				'default_value' => 400,
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
			array (
				'key' => 'field_51e106a9fd84b',
				'label' => 'Homepage',
				'name' => '',
				'type' => 'tab',
			),
			array (
				'key' => 'field_51e11262c59ls',
				'label' => 'Display Categories Filter',
				'name' => 'display_categories_filter',
				'type' => 'true_false',
				'instructions' => 'Select if you wish to display the categories filter into the homepage page template called "Homepage With Map And Custom Content". To add the categories filter into the other homepage page template, you can use the editor below here if you enabled the custom tabs layout. Otherwise if using the default tabs, they will only be visible when using the ajax map system. The ajax map system needs to be enabled in any both cases.',
				'message' => 'Display Categories Filter',
				'default_value' => 1,
			),
			array (
				'key' => 'field_51e11262c59fa',
				'label' => 'Display Homepage Sidebar',
				'name' => 'display_homepage_sidebar',
				'type' => 'true_false',
				'instructions' => 'Select if you wish to display the homepage sidebar.',
				'message' => 'Display Homepage Sidebar',
				'default_value' => 1,
			),
			array (
				'key' => 'field_51e12163d15e8',
				'label' => 'Sidebar Tabs Generator',
				'name' => '',
				'type' => 'message',
				'conditional_logic' => array (
					'status' => 1,
					'rules' => array (
						array (
							'field' => 'field_51e11262c59fa',
							'operator' => '==',
							'value' => '1',
						),
					),
					'allorany' => 'all',
				),
				'message' => '<h1>Tabs Generator Information</h1>
	<h2>The tabs generator gives you extreme flexibility over the content on the sidebar of the homepage. The default content of the sidebar is enabled automatically. If you wish to customize the content, simply disable the option below here "Display Default Content", when disabled you will be able to add and generate new tabs with an easy to use editor.</h2>',
			),
			array (
				'key' => 'field_51e124ed1e6e5',
				'label' => 'Display Default Content',
				'name' => 'home_sidebar_display_default_content',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you wish to display default content inside the homepage sidebar.',
				'conditional_logic' => array (
					'status' => 1,
					'rules' => array (
						array (
							'field' => 'field_51e11262c59fa',
							'operator' => '==',
							'value' => '1',
						),
					),
					'allorany' => 'all',
				),
				'message' => 'Display Default Content',
				'default_value' => 1,
			),
			array (
				'key' => 'field_51e140d2851dd',
				'label' => 'Homepage Tabs Generator',
				'name' => 'homepage_tabs_generator',
				'type' => 'flexible_content',
				'instructions' => 'Use the editor here to customize tabs on the homepage sidebar.',
				'conditional_logic' => array (
					'status' => 1,
					'rules' => array (
						array (
							'field' => 'field_51e124ed1e6e5',
							'operator' => '!=',
							'value' => '1',
						),
					),
					'allorany' => 'all',
				),
				'layouts' => array (
					array (
						'label' => 'Add New Tab',
						'name' => 'add_new_tab',
						'display' => 'row',
						'sub_fields' => array (
							array (
								'key' => 'field_51e1430475d71',
								'label' => 'Tab Icon',
								'name' => 'tab_icon',
								'type' => 'text',
								'instructions' => 'Enter the icon name, like displayed on the demo or the documentation.',
								'column_width' => '',
								'default_value' => 'icon-plus',
								'placeholder' => '',
								'prepend' => '',
								'append' => '',
								'formatting' => 'html',
								'maxlength' => '',
							),
							array (
								'key' => 'field_51e1434f75d72',
								'label' => 'Set Tab Content',
								'name' => 'set_tab_content',
								'type' => 'select',
								'instructions' => 'Select what kind of content this tab will have.',
								'column_width' => '',
								'choices' => array (
									'Custom Content' => 'Custom Content',
									'Latest Listings' => 'Latest Listings',
									'Featured Listings' => 'Featured Listings',
									'User Area' => 'User Area',
									'Search Form' => 'Search Form',
									'Single Taxonomy' => 'Single Taxonomy',
									'Categories Filter' => 'Categories Filter',
								),
								'default_value' => 'Custom Content',
								'allow_null' => 0,
								'multiple' => 0,
							),
							array (
								'key' => 'field_51e1430475d76',
								'label' => 'Single Taxonomy ID',
								'name' => 'single_tax_id',
								'type' => 'text',
								'instructions' => 'Enter the taxonomy ID number if you wish to display a single category into this tab. Note you must select the option "Single Taxonomy" from the setting above.',
								'column_width' => '',
								'default_value' => '',
								'placeholder' => '',
								'prepend' => '',
								'append' => '',
								'formatting' => 'html',
								'maxlength' => '',
							),
							array (
								'key' => 'field_51e1444d75d73',
								'label' => 'Tab Content',
								'name' => 'tab_content',
								'type' => 'wysiwyg',
								'instructions' => 'Enter the content of the tab.',
								'column_width' => '',
								'default_value' => '',
								'toolbar' => 'full',
								'media_upload' => 'no',
							),
						),
					),
				),
				'button_label' => 'Add New Tab',
			),
			array (
				'key' => 'field_523711afb7fe6',
				'label' => 'Homepage Slider Shortcode',
				'name' => 'homepage_slider_shortcode',
				'type' => 'text',
				'instructions' => 'Insert the layer slider shortcode here. This will allow you to display a slider on the homepage. <strong>Note: the slider is only available on the homepage with slider page template. You can\'t use the slider on the homepage template with the map.</strong>',
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),

			array (
				'key' => 'field_526a50d5c4735',
				'label' => 'Map Start Point',
				'name' => '',
				'type' => 'tab',
			),
			array (
				'key' => 'field_526a502ac0b74',
				'label' => 'Disable Map Autofit',
				'name' => 'disable_map_autofit',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you wish to disable the map autofit. This allows you to set a custom center point on the map.',
				'message' => '',
				'default_value' => 0,
			),
			array (
				'key' => 'field_526a504fc0b75',
				'label' => 'Custom Map Center',
				'name' => 'custom_map_center',
				'type' => 'location-field',
				'instructions' => 'Set a custom location as starting point on the map.',
				'val' => 'coordinates',
				'center' => '48.856614,2.3522219000000177',
				'zoom' => 10,
				'scrollwheel' => 1,
			),
			array (
				'key' => 'field_526a5076c0b76',
				'label' => 'Adjust Zoom',
				'name' => 'adjust_zoom',
				'type' => 'number',
				'instructions' => 'Set a custom zoom value as a start for the map.',
				'default_value' => 10,
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'min' => '',
				'max' => '',
				'step' => '',
			),
			array (
				'key' => 'field_526a5089c0b77',
				'label' => 'Geolocation Zoom',
				'name' => 'geolocation_zoom',
				'type' => 'number',
				'instructions' => 'Set a custom zoom value for the geolocation map.',
				'default_value' => 5,
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'min' => '',
				'max' => '',
				'step' => '',
			),


		),
		'location' => array (
			array (
				array (
					'param' => 'options_page',
					'operator' => '==',
					'value' => 'acf-options-theme-options',
					'order_no' => 0,
					'group_no' => 0,
				),
			),
		),
		'options' => array (
			'position' => 'normal',
			'layout' => 'default',
			'hide_on_screen' => array (
			),
		),
		'menu_order' => 0,
	));
	register_field_group(array (
		'id' => 'acf_user-dashboard-settings',
		'title' => 'User Dashboard Settings',
		'fields' => array (
			array (
				'key' => 'field_522ba75786ba5',
				'label' => 'Dashboard Page',
				'name' => 'listings_management_page',
				'type' => 'page_link',
				'instructions' => 'Select the page where you have added the [efe_dashboard] shortcode.',
				'post_type' => array (
					0 => 'page',
				),
				'allow_null' => 0,
				'multiple' => 0,
			),
			array (
				'key' => 'field_522ba7988183fff',
				'label' => 'Login Page',
				'name' => 'login_page_url',
				'type' => 'page_link',
				'instructions' => 'Select the page where you have applied the "Login Page" Page template.',
				'post_type' => array (
					0 => 'page',
				),
				'allow_null' => 0,
				'multiple' => 0,
			),
			array (
				'key' => 'field_522ba7988183ffd',
				'label' => 'Password Recovery Page',
				'name' => 'password_recovery_page_url',
				'type' => 'page_link',
				'instructions' => 'Select the page where you have applied the "Password Recovery Form" Page template.',
				'post_type' => array (
					0 => 'page',
				),
				'allow_null' => 0,
				'multiple' => 0,
			),
			array (
				'key' => 'field_522ba7988183ff9',
				'label' => 'Password Recovery Successfull',
				'name' => 'recovery_success_url',
				'type' => 'page_link',
				'instructions' => 'Select the page where want to redirect your users after the successfully reset their password',
				'post_type' => array (
					0 => 'page',
				),
				'allow_null' => 0,
				'multiple' => 0,
			),
			array (
				'key' => 'field_522ba79881839',
				'label' => 'Submit New Listing Page',
				'name' => 'submit_new_listing_page',
				'type' => 'page_link',
				'instructions' => 'Select the page where you have applied the "Submit Listing" Page template.',
				'post_type' => array (
					0 => 'page',
				),
				'allow_null' => 0,
				'multiple' => 0,
			),
			array (
				'key' => 'field_522ef4b5b7813',
				'label' => 'Edit Profile Page',
				'name' => 'edit_profile_page',
				'type' => 'page_link',
				'instructions' => 'Select the page with the "edit profile" page template applied. This is the page where users can change their details and password.',
				'post_type' => array (
					0 => 'page',
				),
				'allow_null' => 0,
				'multiple' => 0,
			),
			array (
				'key' => 'field_5231d768ed184',
				'label' => 'Edit Listings Page',
				'name' => 'redirect_edit_listings_page',
				'type' => 'page_link',
				'instructions' => 'Select the page where you have applied the page template "Edit Listing Page". This page is needed to edit listings from the backend.',
				'post_type' => array (
					0 => 'page',
				),
				'allow_null' => 0,
				'multiple' => 0,
			),
			array (
				'key' => 'field_5221bba22c5fd',
				'label' => 'Dashboard Restricted Access Message',
				'name' => 'efe_dashboard_restricted_access_message',
				'type' => 'wysiwyg',
				'instructions' => 'Enter the message that non logged in users will see if they try to access this page before logging in.',
				'default_value' => 'Access to this page is restricted to logged in users only, please login before using the user dashboard.',
				'toolbar' => 'full',
				'media_upload' => 'yes',
			),
			array (
				'key' => 'field_5221bbcc2c5fe',
				'label' => 'Dashboard Display Settings',
				'name' => 'efe_dashboard_display_settings',
				'type' => 'checkbox',
				'instructions' => 'Select what elements you want to hide or display on the frontend. Uncheck an option to disable it.',
				'choices' => array (
					'Display Listings Graph' => 'Display Listings Graph',
					'Display Page Head' => 'Display Page Head',
					'Display Post Count' => 'Display Post Count',
					'Display Featured Images' => 'Display Featured Images',
					'Display Post Title' => 'Display Post Title',
					'Display Post Status' => 'Display Post Status',
					'Display Options' => 'Display Options',
				),
				'default_value' => 'Display Page Head
	Display Post Count
	Display Featured Images
	Display Post Title
	Display Post Status
	Display Options',
				'layout' => 'vertical',
			),
			array (
				'key' => 'field_5221bc0c2c5ff',
				'label' => 'User Posting Restrictions',
				'name' => 'efe_user_posting_restrictions',
				'type' => 'checkbox',
				'instructions' => 'Select what actions a users can take in his dashboard.',
				'choices' => array (
					'Allow Users To Edit Their Posts' => 'Allow Users To Edit Their Posts',
					'Allow Users To Delete Their Posts' => 'Allow Users To Delete Their Posts',
				),
				'default_value' => 'Allow Users To Edit Their Posts
	Allow Users To Delete Their Posts',
				'layout' => 'vertical',
			),
			array (
				'key' => 'field_5221bc392c600',
				'label' => 'Posts Per Page',
				'name' => 'efe_posts_per_page',
				'type' => 'number',
				'instructions' => 'Select how many posts per page you would like to display inside the dashboard.',
				'default_value' => 12,
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'min' => 1,
				'max' => '',
				'step' => '',
			),
		),
		'location' => array (
			array (
				array (
					'param' => 'options_page',
					'operator' => '==',
					'value' => 'acf-options-user-dashboard',
					'order_no' => 0,
					'group_no' => 0,
				),
			),
		),
		'options' => array (
			'position' => 'normal',
			'layout' => 'default',
			'hide_on_screen' => array (
			),
		),
		'menu_order' => 0,
	));
}


/**
 *  Register Field Restrictions Page Settings
 */

if(function_exists("register_field_group"))
{
	register_field_group(array (
		'id' => 'acf_membership-fields-restrictions',
		'title' => 'Membership Fields Restrictions',
		'fields' => array (
			array (
				'key' => 'field_52614f4436c1c',
				'label' => 'Fields Restrictions',
				'name' => '',
				'type' => 'message',
				'message' => '<h2>How does it work?</h2>
	Through this area you can setup restrictions for submission fields. How does it work? At first you need to create your membership packages, you will then need to take note of the membership ID because this will be required to setup restrictions for each submission field for the frontend.
	
	You will use the membership ID as requirement for the field to be displayed on frontend, it means that when a user purchases that membership he will then have access to the fields.
	
	To enable the system please enable the option below here, new options will the be visible once the restriction system is enabled.',
			),
			array (
				'key' => 'field_526151f4538da',
				'label' => 'Enable Fields Restriction System',
				'name' => 'enable_fields_restriction_system',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you want to restrict access to certain fields from the frontend.
	
	Note: you as admin will always be able to see fields from frontend.',
				'message' => '',
				'default_value' => 0,
			),
			array (
				'key' => 'field_52615238538db',
				'label' => 'Restrict Category Selection Field',
				'name' => 'restrict_category_selection_field',
				'type' => 'text',
				'instructions' => 'Enter the membership(s) ID(s) of one or more memberships that are allowed to use this field. If you leave this field blank, it will be accessible to everyone. Separate multiple memberships with a comma, for example 1, 2, 3 etc..',
				'conditional_logic' => array (
					'status' => 1,
					'rules' => array (
						array (
							'field' => 'field_526151f4538da',
							'operator' => '==',
							'value' => '1',
						),
					),
					'allorany' => 'all',
				),
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
			array (
				'key' => 'field_52615292538dc',
				'label' => 'Restrict Location Area Selection Field',
				'name' => 'restrict_location_selection_field',
				'type' => 'text',
				'instructions' => 'Enter the membership(s) ID(s) of one or more memberships that are allowed to use this field. If you leave this field blank, it will be accessible to everyone. Separate multiple memberships with a comma, for example 1, 2, 3 etc..',
				'conditional_logic' => array (
					'status' => 1,
					'rules' => array (
						array (
							'field' => 'field_526151f4538da',
							'operator' => '==',
							'value' => '1',
						),
					),
					'allorany' => 'all',
				),
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
			array (
				'key' => 'field_526152c0538de',
				'label' => 'Restrict Telephone Field',
				'name' => 'restrict_telephone_field',
				'type' => 'text',
				'instructions' => 'Enter the membership(s) ID(s) of one or more memberships that are allowed to use this field. If you leave this field blank, it will be accessible to everyone. Separate multiple memberships with a comma, for example 1, 2, 3 etc..',
				'conditional_logic' => array (
					'status' => 1,
					'rules' => array (
						array (
							'field' => 'field_526151f4538da',
							'operator' => '==',
							'value' => '1',
						),
					),
					'allorany' => 'all',
				),
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
			array (
				'key' => 'field_526152dc538df',
				'label' => 'Restrict Mobile Field',
				'name' => 'restrict_mobile_field',
				'type' => 'text',
				'instructions' => 'Enter the membership(s) ID(s) of one or more memberships that are allowed to use this field. If you leave this field blank, it will be accessible to everyone. Separate multiple memberships with a comma, for example 1, 2, 3 etc..',
				'conditional_logic' => array (
					'status' => 1,
					'rules' => array (
						array (
							'field' => 'field_526151f4538da',
							'operator' => '==',
							'value' => '1',
						),
					),
					'allorany' => 'all',
				),
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
			array (
				'key' => 'field_52615316538e1',
				'label' => 'Restrict Website Field',
				'name' => 'restrict_website_field',
				'type' => 'text',
				'instructions' => 'Enter the membership(s) ID(s) of one or more memberships that are allowed to use this field. If you leave this field blank, it will be accessible to everyone. Separate multiple memberships with a comma, for example 1, 2, 3 etc..',
				'conditional_logic' => array (
					'status' => 1,
					'rules' => array (
						array (
							'field' => 'field_526151f4538da',
							'operator' => '==',
							'value' => '1',
						),
					),
					'allorany' => 'all',
				),
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
			array (
				'key' => 'field_5261536e3cc53',
				'label' => 'Restrict Custom Fields Builder Field',
				'name' => 'restrict_custom_field',
				'type' => 'text',
				'instructions' => 'Enter the membership(s) ID(s) of one or more memberships that are allowed to use this field. If you leave this field blank, it will be accessible to everyone. Separate multiple memberships with a comma, for example 1, 2, 3 etc..',
				'conditional_logic' => array (
					'status' => 1,
					'rules' => array (
						array (
							'field' => 'field_526151f4538da',
							'operator' => '==',
							'value' => '1',
						),
					),
					'allorany' => 'all',
				),
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
			array (
				'key' => 'field_52615399f64ff',
				'label' => 'Restrict Opening Times Fields',
				'name' => 'restrict_opening_field',
				'type' => 'text',
				'instructions' => 'Enter the membership(s) ID(s) of one or more memberships that are allowed to use this field. If you leave this field blank, it will be accessible to everyone. Separate multiple memberships with a comma, for example 1, 2, 3 etc..',
				'conditional_logic' => array (
					'status' => 1,
					'rules' => array (
						array (
							'field' => 'field_526151f4538da',
							'operator' => '==',
							'value' => '1',
						),
					),
					'allorany' => 'all',
				),
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
			array (
				'key' => 'field_526153bbf6501',
				'label' => 'Restrict Featured Image Field',
				'name' => 'restrict_featured_image_field',
				'type' => 'text',
				'instructions' => 'Enter the membership(s) ID(s) of one or more memberships that are allowed to use this field. If you leave this field blank, it will be accessible to everyone. Separate multiple memberships with a comma, for example 1, 2, 3 etc..',
				'conditional_logic' => array (
					'status' => 1,
					'rules' => array (
						array (
							'field' => 'field_526151f4538da',
							'operator' => '==',
							'value' => '1',
						),
					),
					'allorany' => 'all',
				),
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
			array (
				'key' => 'field_526153def6503',
				'label' => 'Restrict Additional Image 1',
				'name' => 'restrict_additional_image1',
				'type' => 'text',
				'instructions' => 'Enter the membership(s) ID(s) of one or more memberships that are allowed to use this field. If you leave this field blank, it will be accessible to everyone. Separate multiple memberships with a comma, for example 1, 2, 3 etc..',
				'conditional_logic' => array (
					'status' => 1,
					'rules' => array (
						array (
							'field' => 'field_526151f4538da',
							'operator' => '==',
							'value' => '1',
						),
					),
					'allorany' => 'all',
				),
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
			array (
				'key' => 'field_526153f4f9641',
				'label' => 'Restrict Additional Image 2',
				'name' => 'restrict_additional_image_2',
				'type' => 'text',
				'instructions' => 'Enter the membership(s) ID(s) of one or more memberships that are allowed to use this field. If you leave this field blank, it will be accessible to everyone. Separate multiple memberships with a comma, for example 1, 2, 3 etc..',
				'conditional_logic' => array (
					'status' => 1,
					'rules' => array (
						array (
							'field' => 'field_526151f4538da',
							'operator' => '==',
							'value' => '1',
						),
					),
					'allorany' => 'all',
				),
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
			array (
				'key' => 'field_526153fff9642',
				'label' => 'Restrict Additional Image 3',
				'name' => 'restrict_additional_image_3',
				'type' => 'text',
				'instructions' => 'Enter the membership(s) ID(s) of one or more memberships that are allowed to use this field. If you leave this field blank, it will be accessible to everyone. Separate multiple memberships with a comma, for example 1, 2, 3 etc..',
				'conditional_logic' => array (
					'status' => 1,
					'rules' => array (
						array (
							'field' => 'field_526151f4538da',
							'operator' => '==',
							'value' => '1',
						),
					),
					'allorany' => 'all',
				),
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
			array (
				'key' => 'field_52615406f9643',
				'label' => 'Restrict Additional Image 4',
				'name' => 'restrict_additional_image_4',
				'type' => 'text',
				'instructions' => 'Enter the membership(s) ID(s) of one or more memberships that are allowed to use this field. If you leave this field blank, it will be accessible to everyone. Separate multiple memberships with a comma, for example 1, 2, 3 etc..',
				'conditional_logic' => array (
					'status' => 1,
					'rules' => array (
						array (
							'field' => 'field_526151f4538da',
							'operator' => '==',
							'value' => '1',
						),
					),
					'allorany' => 'all',
				),
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
			array (
				'key' => 'field_5261540ff9644',
				'label' => 'Restrict Additional Image 5',
				'name' => 'restrict_additional_image_5',
				'type' => 'text',
				'instructions' => 'Enter the membership(s) ID(s) of one or more memberships that are allowed to use this field. If you leave this field blank, it will be accessible to everyone. Separate multiple memberships with a comma, for example 1, 2, 3 etc..',
				'conditional_logic' => array (
					'status' => 1,
					'rules' => array (
						array (
							'field' => 'field_526151f4538da',
							'operator' => '==',
							'value' => '1',
						),
					),
					'allorany' => 'all',
				),
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
			array (
				'key' => 'field_5261540ff9645',
				'label' => 'Restrict Video',
				'name' => 'restrict_video',
				'type' => 'text',
				'instructions' => 'Enter the membership(s) ID(s) of one or more memberships that are allowed to use this field. If you leave this field blank, it will be accessible to everyone. Separate multiple memberships with a comma, for example 1, 2, 3 etc..',
				'conditional_logic' => array (
					'status' => 1,
					'rules' => array (
						array (
							'field' => 'field_526151f4538da',
							'operator' => '==',
							'value' => '1',
						),
					),
					'allorany' => 'all',
				),
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'formatting' => 'html',
				'maxlength' => '',
			),
		),
		'location' => array (
			array (
				array (
					'param' => 'options_page',
					'operator' => '==',
					'value' => 'acf-options-fields-restrictions',
					'order_no' => 0,
					'group_no' => 0,
				),
			),
		),
		'options' => array (
			'position' => 'normal',
			'layout' => 'default',
			'hide_on_screen' => array (
			),
		),
		'menu_order' => 0,
	));
}

/**
 *  Install Add-ons
 *  
 *  The following code will include all 4 premium Add-Ons in your theme.
 *  Please do not attempt to include a file which does not exist. This will produce an error.
 *  
 *  The following code assumes you have a folder 'add-ons' inside your theme.
 *
 *  IMPORTANT
 *  Add-ons may be included in a premium theme/plugin as outlined in the terms and conditions.
 *  For more information, please read:
 *  - http://www.advancedcustomfields.com/terms-conditions/
 *  - http://www.advancedcustomfields.com/resources/getting-started/including-lite-mode-in-a-plugin-theme/
 */ 

// Add-ons 
// include_once('add-ons/acf-repeater/acf-repeater.php');
// include_once('add-ons/acf-gallery/acf-gallery.php');
// include_once('add-ons/acf-flexible-content/acf-flexible-content.php');
// include_once( 'add-ons/acf-options-page/acf-options-page.php' );


/**
 *  Register Field Groups
 *
 *  The register_field_group function accepts 1 array which holds the relevant data to register a field group
 *  You may edit the array as you see fit. However, this may result in errors if the array is not compatible with ACF
 */

if(function_exists("register_field_group"))
{
	register_field_group(array (
		'id' => 'acf_search-fields-customization',
		'title' => 'Search Fields Customization',
		'fields' => array (
			array (
				'key' => 'field_526a551a651ea',
				'label' => 'Default Fields',
				'name' => '',
				'type' => 'tab',
			),

			array (
				'key' => 'field_526a5529650eb',
				'label' => 'Enable Search By Address On Map',
				'name' => 'enable_search_on_map',
				'instructions' => 'Enable this option if you wish to display a search by address field on the search form.',
				'type' => 'true_false',
				'message' => '',
				'default_value' => 1,
			),

			array (
				'key' => 'field_526a5529650fac',
				'label' => 'Enable Faceted Search',
				'name' => 'enable_faceted_search',
				'instructions' => 'Enable this option if you wish enable the faceted search mode on the search form.',
				'type' => 'true_false',
				'message' => '',
				'default_value' => 0,
			),

			array (
				'key' => 'field_526a5529651eb',
				'label' => 'Disable Search Input Text',
				'name' => 'disable_search_input_text',
				'instructions' => 'Enable this option if you wish to disable this field.',
				'type' => 'true_false',
				'message' => '',
				'default_value' => 0,
			),
			array (
				'key' => 'field_526a554c651ec',
				'label' => 'Disable Listings Categories Field',
				'name' => 'disable_listings_categories_field',
				'instructions' => 'Enable this option if you wish to disable this field.',
				'type' => 'true_false',
				'message' => '',
				'default_value' => 0,
			),
			array (
				'key' => 'field_526a5560651ed',
				'label' => 'Disable Listings Location Field',
				'name' => 'disable_listings_location_field',
				'instructions' => 'Enable this option if you wish to disable this field.',
				'type' => 'true_false',
				'message' => '',
				'default_value' => 0,
			),
			array (
				'key' => 'field_526a556f651ee',
				'label' => 'Disable Featured Listings Lookup Field',
				'name' => 'disable_featured_listings_lookup_field',
				'instructions' => 'Enable this option if you wish to disable this field.',
				'type' => 'true_false',
				'message' => '',
				'default_value' => 0,
			),
			array (
				'key' => 'field_527bb34d84bc4',
				'label' => 'Custom Search Fields',
				'name' => '',
				'type' => 'tab',
			),
			array (
				'key' => 'field_527bb35884bc5',
				'label' => 'Search Form Custom Fields Builder',
				'name' => 'search_form_custom_fields_builder',
				'type' => 'flexible_content',
				'instructions' => 'Press the "add new field" button to start adding your new fields. Follow the instructions of each field to make sure that your form will work.',
				'layouts' => array (
					array (
						'label' => 'Author Field',
						'name' => 'author_field',
						'display' => 'row',
						'sub_fields' => array (
							array (
								'key' => 'field_527bb5e684bc6',
								'label' => 'Field Label',
								'name' => 'field_label',
								'type' => 'text',
								'instructions' => 'Enter the label for this field',
								'column_width' => '',
								'default_value' => '',
								'placeholder' => '',
								'prepend' => '',
								'append' => '',
								'formatting' => 'html',
								'maxlength' => '',
							),
							array (
								'key' => 'field_527bb61b84bc7',
								'label' => 'Field Format',
								'name' => 'field_format',
								'type' => 'select',
								'instructions' => 'Sets the format of the field',
								'column_width' => '',
								'choices' => array (
									'select' => 'select',
									'multi-select' => 'multi-select',
									'checkbox' => 'checkbox',
									'radio' => 'radio',
								),
								'default_value' => '',
								'allow_null' => 0,
								'multiple' => 0,
							),
							array (
								'key' => 'field_527bb67384bc8',
								'label' => 'Default Value',
								'name' => 'default_value',
								'type' => 'text',
								'instructions' => 'A user ID number. If you set this field, it will automatically set the default value to the user ID that you set. Meaning the search form will look for this default author first.',
								'column_width' => 30,
								'default_value' => '',
								'placeholder' => '',
								'prepend' => '',
								'append' => '',
								'formatting' => 'html',
								'maxlength' => '',
							),
						),
					),
					array (
						'label' => 'Html',
						'name' => 'html',
						'display' => 'row',
						'sub_fields' => array (
							array (
								'key' => 'field_527bb82c638d5',
								'label' => 'Content',
								'name' => 'content',
								'type' => 'textarea',
								'instructions' => 'The html field is not really a field, but rather a means for inserting HTML content inside your form.	In certain instances you may find the need to include custom markup between individual fields, and in these cases the html field is the perfect solution.',
								'column_width' => '',
								'default_value' => '',
								'placeholder' => '',
								'maxlength' => '',
								'formatting' => 'html',
							),
						),
					),
					array (
						'label' => 'Meta Key (Custom Field)',
						'name' => 'meta_key',
						'display' => 'row',
						'sub_fields' => array (
							array (
								'key' => 'field_527bb86f3f639',
								'label' => 'Field Label',
								'name' => 'field_label',
								'type' => 'text',
								'instructions' => 'Enter the label for this field',
								'column_width' => '',
								'default_value' => '',
								'placeholder' => '',
								'prepend' => '',
								'append' => '',
								'formatting' => 'html',
								'maxlength' => '',
							),
							array (
								'key' => 'field_527bb86f3f63a',
								'label' => 'Field Format',
								'name' => 'field_format',
								'type' => 'select',
								'instructions' => 'Sets the format of the field',
								'column_width' => '',
								'choices' => array (
									'select' => 'select',
									'multi-select' => 'multi-select',
									'checkbox' => 'checkbox',
									'radio' => 'radio',
									'text' => 'text',
								),
								'default_value' => '',
								'allow_null' => 0,
								'multiple' => 0,
							),
							array (
								'key' => 'field_527bb8a63f63e',
								'label' => 'Meta Key',
								'name' => 'meta_key',
								'type' => 'text',
								'instructions' => 'Used when creating meta_key fields, this parameter specifies the meta key that the field should correspond to. Basically this is the name/id of the custom field that this search field will be searching for.',
								'column_width' => 20,
								'default_value' => '',
								'placeholder' => '',
								'prepend' => '',
								'append' => '',
								'formatting' => 'html',
								'maxlength' => '',
							),
							array (
								'key' => 'field_527bb91d3f63f',
								'label' => 'Values',
								'name' => 'values',
								'type' => 'textarea',
								'instructions' => 'Use this field to populate your selectable field, you must fill this field ONLY when the field format option above, isn\'t "text". To add options simply follow the following format: <br><br/> field_value=Option Label <br/><br/> <strong>"field_value"</strong> stands for the option that your custom listing field might have, it\'s also the value that the search form will look for. <br/><br/> <strong>"Option Label" </strong> is the name of the option that the user will see into the search form. To add multiple options simply add the symbol % in the middle of each option. <br/><br/> Example: test1=label1%test2=label2',
								'column_width' => 20,
								'default_value' => 'test1=label1%test2=label2',
								'placeholder' => '',
								'maxlength' => '',
								'formatting' => 'none',
							),
							array (
								'key' => 'field_527bbb4c3f640',
								'label' => 'Compare',
								'name' => 'compare',
								'type' => 'select',
								'instructions' => 'This is the criteria that will be used to search for the custom field.',
								'column_width' => 20,
								'choices' => array (
									'=' => '=',
									'!=' => '!=',
									'>' => '>',
									'>=' => '>=',
									'<' => '<',
									'<=' => '<=',
									'LIKE' => 'LIKE',
									'NOT LIKE' => 'NOT LIKE',
									'IN' => 'IN',
									'NOT IN' => 'NOT IN',
									'BETWEEN' => 'BETWEEN',
									'NOT BETWEEN' => 'NOT BETWEEN',
									'EXISTS' => 'EXISTS',
									'NOT EXISTS' => 'NOT EXISTS',
								),
								'default_value' => '',
								'allow_null' => 0,
								'multiple' => 0,
							),
							array (
								'key' => 'field_527bbcb13f641',
								'label' => 'Data Type',
								'name' => 'data_type',
								'type' => 'select',
								'instructions' => 'Used with meta_key fields to specify the type of data stored by the meta_key. Necessary in order to perform proper comparison operations',
								'column_width' => '',
								'choices' => array (
									'NUMERIC' => 'NUMERIC',
									'BINARY' => 'BINARY',
									'CHAR' => 'CHAR',
									'DATE' => 'DATE',
									'DATETIME' => 'DATETIME',
									'DECIMAL' => 'DECIMAL',
									'SIGNED' => 'SIGNED',
									'TIME' => 'TIME',
									'UNSIGNED' => 'UNSIGNED',
								),
								'default_value' => 'CHAR',
								'allow_null' => 0,
								'multiple' => 0,
							),
							array (
								'key' => 'field_527bbd1a3f642',
								'label' => 'Default',
								'name' => 'default',
								'type' => 'text',
								'instructions' => 'Sets a field’s default value,',
								'column_width' => '',
								'default_value' => '',
								'placeholder' => '',
								'prepend' => '',
								'append' => '',
								'formatting' => 'html',
								'maxlength' => '',
							),
						),
					),
					array (
						'label' => 'Taxonomy',
						'name' => 'taxonomy',
						'display' => 'row',
						'sub_fields' => array (
							array (
								'key' => 'field_527bbe494e783',
								'label' => 'Field Label',
								'name' => 'field_label',
								'type' => 'text',
								'instructions' => 'Enter the label for this field',
								'column_width' => '',
								'default_value' => '',
								'placeholder' => '',
								'prepend' => '',
								'append' => '',
								'formatting' => 'html',
								'maxlength' => '',
							),
							array (
								'key' => 'field_527bbe494e784',
								'label' => 'Field Format',
								'name' => 'field_format',
								'type' => 'select',
								'instructions' => 'Sets the format of the field',
								'column_width' => '',
								'choices' => array (
									'select' => 'select',
									'multi-select' => 'multi-select',
									'checkbox' => 'checkbox',
									'radio' => 'radio',
								),
								'default_value' => '',
								'allow_null' => 0,
								'multiple' => 0,
							),
							array (
								'key' => 'field_527bbe9f4e78a',
								'label' => 'Taxonomy Name',
								'name' => 'taxonomy_name',
								'type' => 'text',
								'instructions' => 'Enter the name of the taxonomy',
								'column_width' => '',
								'default_value' => '',
								'placeholder' => '',
								'prepend' => '',
								'append' => '',
								'formatting' => 'html',
								'maxlength' => '',
							),
							array (
								'key' => 'field_527bbed04e78b',
								'label' => 'Hide Empty ?',
								'name' => 'hide_empty',
								'type' => 'true_false',
								'instructions' => 'Enable this option if you wish to disable empty categories in the taxonomy',
								'column_width' => '',
								'message' => '',
								'default_value' => 0,
							),
							array (
								'key' => 'field_527bbef14e78c',
								'label' => 'Exclude Terms',
								'name' => 'exclude_terms',
								'type' => 'text',
								'instructions' => 'Enter the ID(s) separated by a comma of each term that you wish to exclude.',
								'column_width' => '',
								'default_value' => '',
								'placeholder' => '',
								'prepend' => '',
								'append' => '',
								'formatting' => 'html',
								'maxlength' => '',
							),
							array (
								'key' => 'field_527bbf1e4e78d',
								'label' => 'Operator',
								'name' => 'operator',
								'type' => 'select',
								'instructions' => 'This is the criteria that will be used to search for the custom field.',
								'column_width' => '',
								'choices' => array (
									'IN' => 'IN',
									'NOT IN' => 'NOT IN',
									'AND' => 'AND',
								),
								'default_value' => 'IN',
								'allow_null' => 0,
								'multiple' => 0,
							),
							array (
								'key' => 'field_527bbf574e78e',
								'label' => 'Default',
								'name' => 'default',
								'type' => 'text',
								'instructions' => 'Enter the ID of the default selected term. (Optional)',
								'column_width' => '',
								'default_value' => '',
								'placeholder' => '',
								'prepend' => '',
								'append' => '',
								'formatting' => 'html',
								'maxlength' => '',
							),
						),
					),
					array (
						'label' => 'Pre Configured Field: Listings Tags',
						'name' => 'listings_tags',
						'display' => 'row',
						'sub_fields' => array (
							array (
								'key' => 'field_527bbff3d5029',
								'label' => 'Field Label',
								'name' => 'field_label',
								'type' => 'text',
								'instructions' => 'Enter the label for this field',
								'column_width' => '',
								'default_value' => '',
								'placeholder' => '',
								'prepend' => '',
								'append' => '',
								'formatting' => 'html',
								'maxlength' => '',
							),
							array (
								'key' => 'field_527bbff3d502a',
								'label' => 'Field Format',
								'name' => 'field_format',
								'type' => 'select',
								'instructions' => 'Sets the format of the field',
								'column_width' => '',
								'choices' => array (
									'select' => 'select',
									'multi-select' => 'multi-select',
									'checkbox' => 'checkbox',
									'radio' => 'radio',
								),
								'default_value' => '',
								'allow_null' => 0,
								'multiple' => 0,
							),
							array (
								'key' => 'field_527bc014d5030',
								'label' => 'Pre Conf',
								'name' => '',
								'type' => 'message',
								'column_width' => '',
								'message' => 'This is a preconfigured field, meaning it doesn\'t require any setup, you just need to configure the field label and format. And it will be ready to be used. This field will search for listings tags.',
							),
						),
					),
				),
				'button_label' => 'Add New Field',
			),
		),
		'location' => array (
			array (
				array (
					'param' => 'options_page',
					'operator' => '==',
					'value' => 'acf-options-search-form-fields',
					'order_no' => 0,
					'group_no' => 0,
				),
			),
		),
		'options' => array (
			'position' => 'normal',
			'layout' => 'default',
			'hide_on_screen' => array (
			),
		),
		'menu_order' => 0,
	));
}

if(function_exists("register_field_group"))
{
	register_field_group(array (
		'id' => 'acf_skin-customization',
		'title' => 'Skin Customization',
		'fields' => array (
			array (
				'key' => 'field_52d1459f0f1c2',
				'label' => __('Skin Type'),
				'name' => 'skin_type',
				'type' => 'select',
				'instructions' => __('Select the skin type. Select the option "Custom Skin" if you wish to use the custom controls below here.'),
				'choices' => array (
					'default' => 'default',
					'skin2' => 'skin2',
					'skin3' => 'skin3',
					'skin4' => 'skin4',
					'skin5' => 'skin5',
					'skin6' => 'skin6',
					'skin7' => 'skin7',
					'Custom Skin' => 'Custom Skin',
				),
				'default_value' => 'default',
				'allow_null' => 0,
				'multiple' => 0,
			),
			array (
				'key' => 'field_52d1461e0f1c3',
				'label' => __('Topbar Gradient Start'),
				'name' => 'topbar_gradient_start',
				'type' => 'color_picker',
				'default_value' => '#252525',
			),
			array (
				'key' => 'field_52d146310f1c4',
				'label' => __('Topbar gradient end'),
				'name' => 'topbar_gradient_end',
				'type' => 'color_picker',
				'default_value' => '#393939',
			),
			array (
				'key' => 'field_52d146440f1c5',
				'label' => __('Topbar text color'),
				'name' => 'topbar_text_color',
				'type' => 'color_picker',
				'default_value' => '#A7A7A7',
			),
			array (
				'key' => 'field_52d146590f1c6',
				'label' => __('Topbar links color'),
				'name' => 'topbar_links_color',
				'type' => 'color_picker',
				'default_value' => '#fff',
			),
			array (
				'key' => 'field_52d146680f1c7',
				'label' => __('Header Color'),
				'name' => 'header_color',
				'type' => 'color_picker',
				'default_value' => '#fff',
			),
			array (
				'key' => 'field_52d146790f1c8',
				'label' => __('Header Links Color'),
				'name' => 'header_links_color',
				'type' => 'color_picker',
				'default_value' => '#979797',
			),
			array (
				'key' => 'field_52d146890f1c9',
				'label' => __('Header Active Link Color'),
				'name' => 'header_active_link_color',
				'type' => 'color_picker',
				'default_value' => '#212121',
			),
			array (
				'key' => 'field_52d146960f1ca',
				'label' => __('Homepage Sidebar Bg Color'),
				'name' => 'homepage_sidebar_bg_color',
				'type' => 'color_picker',
				'default_value' => '#262F3A',
			),
			array (
				'key' => 'field_52d146a50f1cb',
				'label' => __('Homepage Sidebar Tabs Bg Color'),
				'name' => 'homepage_sidebar_tabs_bg_color',
				'type' => 'color_picker',
				'default_value' => '#fff',
			),
			array (
				'key' => 'field_52d146b20f1cc',
				'label' => __('Homepage Sidebar Tabs Icon Color'),
				'name' => 'homepage_sidebar_tabs_icon_color',
				'type' => 'color_picker',
				'default_value' => '#8a8a8a',
			),
			array (
				'key' => 'field_52d146c30f1cd',
				'label' => __('Homepage Sidebar Tabs Icon Active Color'),
				'name' => 'homepage_sidebar_tabs_icon_active_color',
				'type' => 'color_picker',
				'default_value' => '#fff',
			),
			array (
				'key' => 'field_52d146d30f1ce',
				'label' => __('Homepage Sidebar Tabs Headings Color'),
				'name' => 'homepage_sidebar_tabs_headings_color',
				'type' => 'color_picker',
				'default_value' => '#212121',
			),
			array (
				'key' => 'field_52d146e10f1cf',
				'label' => __('Theme Main Color (Use this option to change the color of various elements of the theme, quick and easy)'),
				'name' => 'theme_main_color',
				'type' => 'color_picker',
				'default_value' => '#212121',
			),
			array (
				'key' => 'field_52d146fa0f1d0',
				'label' => __('Body Font Color'),
				'name' => 'body_font_color',
				'type' => 'color_picker',
				'default_value' => '#616161',
			),
			array (
				'key' => 'field_52d1470a0f1d1',
				'label' => __('Body Background Color'),
				'name' => 'body_background_color',
				'type' => 'color_picker',
				'default_value' => '#ffffff',
			),
			array (
				'key' => 'field_52d147150f1d2',
				'label' => __('Map Pulse Animation Bg Color'),
				'name' => 'map_pulse_animation_bg_color',
				'type' => 'color_picker',
				'default_value' => '#a8a8a8',
			),
			array (
				'key' => 'field_52d147250f1d3',
				'label' => __('Top Footer Background Color'),
				'name' => 'top_footer_background_color',
				'type' => 'color_picker',
				'default_value' => '#171717',
			),
			array (
				'key' => 'field_52d1473f0f1d4',
				'label' => __('Bottom Footer Background Color'),
				'name' => 'bottom_footer_background_color',
				'type' => 'color_picker',
				'default_value' => '#292929',
			),
			array (
				'key' => 'field_52d147500f1d5',
				'label' => __('Bottom Footer Border Color'),
				'name' => 'bottom_footer_border_color',
				'type' => 'color_picker',
				'default_value' => '#353535',
			),
			array (
				'key' => 'field_52d1475f0f1d6',
				'label' => __('Footer Font Color'),
				'name' => 'footer_font_color',
				'type' => 'color_picker',
				'default_value' => '#3a3a3a',
			),
		),
		'location' => array (
			array (
				array (
					'param' => 'options_page',
					'operator' => '==',
					'value' => 'acf-options-skin-customization',
					'order_no' => 0,
					'group_no' => 0,
				),
			),
		),
		'options' => array (
			'position' => 'normal',
			'layout' => 'default',
			'hide_on_screen' => array (
			),
		),
		'menu_order' => 0,
	));
}
