<?php
/**
 * Actions and Filters
 *
 * Register any and all actions here. Nothing should actually be called
 * directly, the entire system will be based on these actions and hooks.
 */
 
/**
 * This is the class that you'll be working with. Duplicate this class as many times as you want. Make sure
 * to include an add_action call to each class, like the line above.
 *
 * @author tdp
 *
 */
class TDP_Listings_Child_Categories extends Empty_Widget_Abstract
{
	/**
	 * Widget settings
	 *
	 * Simply use the following field examples to create the WordPress Widget options that
	 * will display to administrators. These options can then be found in the $params
	 * variable within the widget method.
	 *
	 *
	 */
	protected $widget = array(
		// you can give it a name here, otherwise it will default
		// to the classes name. BTW, you should change the class
		// name each time you create a new widget. Just use find
		// and replace!
		'name' => '[TDP] - Listings Child Categories',
 
		// this description will display within the administrative widgets area
		// when a user is deciding which widget to use.
		'description' => 'Use the following widget to display all the child categories of the current taxonomy in a list. This widget works only into the "Listings Sidebar"',
 
		// determines whether or not to use the sidebar _before and _after html
		'do_wrapper' => true,
 
		// determines whether or not to display the widgets title on the frontend
		'do_title'	=> true,
 
		// string : if you set a filename here, it will be loaded as the view
		// when using a file the following array will be given to the file :
		// array('widget'=>array(),'params'=>array(),'sidebar'=>array(),
		// alternatively, you can return an html string here that will be used
		'view' => false,
	
		// If you desire to change the size of the widget administrative options
		// area
		'width'	=> 350,
		'height' => 350,
	
		// Shortcode button row
		'buttonrow' => 4,
	
		// The image to use as a representation of your widget.
		// Whatever you place here will be used as the img src
		// so we have opted to use a basencoded image.
		'thumbnail' => '',
	
		/* The field options that you have available to you. Please
		 * contribute additional field options if you create any.
		 *
		 */
		'fields' => array(
			// You should always offer a widget title
			array(
				'name' => 'Title',
				'desc' => '',
				'id' => 'title',
				'type' => 'text',
				'default' => 'Listings Child Categories'
			),
			
		)
	);
 
	/**
	 * Widget HTML
	 *
	 * If you want to have an all inclusive single widget file, you can do so by
	 * dumping your css styles with base_encoded images along with all of your
	 * html string, right into this method.
	 *
	 * @param array $widget
	 * @param array $params
	 * @param array $sidebar
	 */
	function html($widget = array(), $params = array(), $sidebar = array())
	{
		
		$term = get_term_by( 'slug', get_query_var( 'term' ), get_query_var( 'taxonomy' ) ); // get current term
        $parent = get_term($term->parent, get_query_var('taxonomy') ); // get parent term
        $children = get_term_children($term->term_id, get_query_var('taxonomy')); // get children

		?>

		<div class="widget_categories widget-num">
			
			<ul>

			<?php 

			$taxonomies = array( get_query_var( 'taxonomy' ) );

	        $args = array(
	            'orderby'       => 'name', 
	            'order'         => 'ASC',
	            'hide_empty'    => false, 
	            'exclude'       => array(), 
	            'exclude_tree'  => array(), 
	            'include'       => array(),
	            'number'        => '', 
	            'fields'        => 'all', 
	            'slug'          => '', 
	            'parent'         => get_queried_object_id(),
	            'hierarchical'  => true, 
	            'child_of'      => 0, 
	            'get'           => '', 
	            'name__like'    => '',
	            'pad_counts'    => false, 
	            'offset'        => '', 
	            'search'        => '', 
	            'cache_domain'  => 'core'
	        );

	        $term_children = get_terms( $taxonomies, $args );


	        if ( ! is_wp_error( $term_children ) && sizeof($term_children)>0 ) {


	            foreach ( $term_children as $child ) {
	                
	                echo '<li>
	                        <a href="' . get_term_link( $child ) . '">' . $child->name . '</a>
	                    </li>';

	            }


	        }

			?>

			</ul>

		</div>

		<?php 
	}
	
}